==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/saml/SAMLAttributeQueryUtil.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 21, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.saml;

import java.security.cert.X509Certificate;

import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;

import eu.unicore.samly2.elements.Subject;
import eu.unicore.samly2.exceptions.SAMLProtocolException;
import eu.unicore.samly2.proto.AssertionResponse;
import eu.unicore.samly2.proto.AttributeQuery;
import eu.unicore.security.dsig.DSigException;

import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.server.CryptoDataProvider;
import pl.edu.icm.unicore.uvos.util.Configuration;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import xmlbeans.org.oasis.saml2.assertion.AttributeType;
import xmlbeans.org.oasis.saml2.assertion.SubjectType;
import xmlbeans.org.oasis.saml2.protocol.AttributeQueryDocument;
import xmlbeans.org.oasis.saml2.protocol.ExtensionsType;
import xmlbeans.pl.edu.icm.samlvo.attrext.RequestedGroupScopeDocument;
import xmlbeans.pl.edu.icm.samlvo.attrext.RequestedGroupScopeType;

/**
 * Utility for handling request->response chain.
 * @author K. Benedyczak
 */
public class SAMLAttributeQueryUtil extends SAMLUtil
{
	private AttributeQueryDocument queryDoc;
	private AttributeQuery query;
	
	private Identity identity;
	private Element element;
	private boolean enforceAssertionSign = false;

	
	public SAMLAttributeQueryUtil(AttributeQueryDocument queryDoc, 
			CryptoDataProvider secProvider, Configuration conf, SAMLConfiguration samlConfig)
	{
		super(queryDoc.getAttributeQuery(), secProvider, conf, samlConfig);
		this.queryDoc = queryDoc;
	}
	
	public void parse() throws SAMLProtocolException
	{
		query = new AttributeQuery(queryDoc);
		SubjectType subject = query.getSubject().getXBean();
		identity = mapSubject(subject);
					
		element = new Element(null, identity);
		ExtensionsType exts = query.getExtensions();
		if (exts == null)
			return;
		XmlCursor cur = exts.newCursor();
		if (!cur.toChild(RequestedGroupScopeDocument.type.getDocumentElementName()))
			return;
		XmlObject scopeRaw = cur.getObject();
		
		cur.dispose();

		if (!(scopeRaw instanceof RequestedGroupScopeType))
			return;
		RequestedGroupScopeType scopeXml = (RequestedGroupScopeType) scopeRaw; 
		String[] scopes = scopeXml.getGroupArray();
		if (scopes == null || scopes.length == 0)
			return;

		element = new Element(new Group(scopes[0]), identity);
	}
	
	public Identity getSubjectIdentity()
	{
		return identity;
	}
	
	public Element getSubjectElement()
	{
		return element;
	}
	
	public Subject getSubject()
	{
		return query.getSubject();
	}
	
	public boolean doSignResponse()
	{
		if (samlConfiguration.isSignRespAlways())
			return true;
		if (samlConfiguration.isSignRespNever())
			return false;
		return query.isSigned();
	}
	
	public void setEnforceSignAssertion(boolean how)
	{
		enforceAssertionSign = how;
	}
	
	public boolean doSignAssertion()
	{
		if (samlConfiguration.isSignAssertAlways() || enforceAssertionSign)
			return true;
		if (samlConfiguration.isSignAssertNever())
			return false;
		if (samlConfiguration.isSignIfRespUnsigned())
			return !doSignResponse();
		return query.isSigned();
	}
	
	public X509Certificate[] getIssuerIdentityFromSignature() 
		throws DSigException
	{
		return getIssuerIdentityFromSignature(query);
	}
	
	public AttributeType[] getQueriedAttributes()
	{
		return query.getAttributes();
	}
	
	public AssertionResponse getOKResponseDocument()
	{
		return new AssertionResponse(getIssuer(), query.getID());
	}
	
	public AssertionResponse getErrorResponse(UVOSException e) 
		throws UVOSFault
	{
		return getErrorResponse(convert2SAMLError(e, null, true));
	}	

	public AssertionResponse getErrorResponse(UVOSException e, String message) 
		throws UVOSFault
	{
		return getErrorResponse(convert2SAMLError(e, message, false));
	}	

	
	public AssertionResponse getErrorResponse(SAMLProtocolException e)
	{
		String id = null;
		if (query == null)
		{
			if (queryDoc != null && queryDoc.getAttributeQuery() != null
				&& queryDoc.getAttributeQuery().getID() != null)
				id = queryDoc.getAttributeQuery().getID();
		} else
			id = query.getID();
		return new AssertionResponse(getIssuer(), id, e);
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/saml/SAMLAttributeQueryUtil.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 21, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.saml;

import java.security.cert.X509Certificate;

import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;

import eu.unicore.samly2.elements.Subject;
import eu.unicore.samly2.exceptions.SAMLProtocolException;
import eu.unicore.samly2.proto.AssertionResponse;
import eu.unicore.samly2.proto.AttributeQuery;
import eu.unicore.security.dsig.DSigException;

import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.server.IssuerIdentityProvider;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import xmlbeans.org.oasis.saml2.assertion.AttributeType;
import xmlbeans.org.oasis.saml2.assertion.SubjectType;
import xmlbeans.org.oasis.saml2.protocol.AttributeQueryDocument;
import xmlbeans.org.oasis.saml2.protocol.ExtensionsType;
import xmlbeans.pl.edu.icm.samlvo.attrext.RequestedGroupScopeDocument;
import xmlbeans.pl.edu.icm.samlvo.attrext.RequestedGroupScopeType;

/**
 * Utility for handling request->response chain.
 * @author K. Benedyczak
 */
public class SAMLAttributeQueryUtil extends SAMLUtil
{
	private AttributeQueryDocument queryDoc;
	private AttributeQuery query;
	
	private Identity identity;
	private Element element;
	private boolean enforceAssertionSign = false;

	
	public SAMLAttributeQueryUtil(AttributeQueryDocument queryDoc, 
			IssuerIdentityProvider secProvider, UVOSServerProperties conf, SAMLConfiguration samlConfig)
	{
		super(queryDoc.getAttributeQuery(), secProvider, conf, samlConfig);
		this.queryDoc = queryDoc;
	}
	
	public void parse() throws SAMLProtocolException
	{
		query = new AttributeQuery(queryDoc);
		SubjectType subject = query.getSubject().getXBean();
		identity = mapSubject(subject);
					
		element = new Element(null, identity);
		ExtensionsType exts = query.getExtensions();
		if (exts == null)
			return;
		XmlCursor cur = exts.newCursor();
		if (!cur.toChild(RequestedGroupScopeDocument.type.getDocumentElementName()))
			return;
		XmlObject scopeRaw = cur.getObject();
		
		cur.dispose();

		if (!(scopeRaw instanceof RequestedGroupScopeType))
			return;
		RequestedGroupScopeType scopeXml = (RequestedGroupScopeType) scopeRaw; 
		String[] scopes = scopeXml.getGroupArray();
		if (scopes == null || scopes.length == 0)
			return;

		element = new Element(new Group(scopes[0]), identity);
	}
	
	public Identity getSubjectIdentity()
	{
		return identity;
	}
	
	public Element getSubjectElement()
	{
		return element;
	}
	
	public Subject getSubject()
	{
		return query.getSubject();
	}
	
	public boolean doSignResponse()
	{
		if (samlConfiguration.isSignRespAlways())
			return true;
		if (samlConfiguration.isSignRespNever())
			return false;
		return query.isSigned();
	}
	
	public void setEnforceSignAssertion(boolean how)
	{
		enforceAssertionSign = how;
	}
	
	public boolean doSignAssertion()
	{
		if (samlConfiguration.isSignAssertAlways() || enforceAssertionSign)
			return true;
		if (samlConfiguration.isSignAssertNever())
			return false;
		if (samlConfiguration.isSignIfRespUnsigned())
			return !doSignResponse();
		return query.isSigned();
	}
	
	public X509Certificate[] getIssuerIdentityFromSignature() 
		throws DSigException
	{
		return getIssuerIdentityFromSignature(query);
	}
	
	public AttributeType[] getQueriedAttributes()
	{
		return query.getAttributes();
	}
	
	public AssertionResponse getOKResponseDocument()
	{
		return new AssertionResponse(getIssuer(), query.getID());
	}
	
	public AssertionResponse getErrorResponse(UVOSException e) 
		throws UVOSFault
	{
		return getErrorResponse(convert2SAMLError(e, null, true));
	}	

	public AssertionResponse getErrorResponse(UVOSException e, String message) 
		throws UVOSFault
	{
		return getErrorResponse(convert2SAMLError(e, message, false));
	}	

	
	public AssertionResponse getErrorResponse(SAMLProtocolException e)
	{
		String id = null;
		if (query == null)
		{
			if (queryDoc != null && queryDoc.getAttributeQuery() != null
				&& queryDoc.getAttributeQuery().getID() != null)
				id = queryDoc.getAttributeQuery().getID();
		} else
			id = query.getID();
		return new AssertionResponse(getIssuer(), id, e);
	}
}
